# Citing

If you use `clinlp` in your research, please cite our work. This helps making `clinlp` findable and accessible to others. You can find the appropriate citation (APA, BibTex, etc.) by clicking the Zenodo button below. This should always point you to the current latest release:

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.10528055.svg)](https://doi.org/10.5281/zenodo.10528055)

You can also find citations for other specific versions on the page above.
